/*
Copyright (©) 2003-2023 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#pragma once

#include <config/libraries.h>

void editone_logic_prefix_html (std::string usfm, std::string stylesheet, std::string & html, std::string & last_p_style);
void editone_logic_editable_html (std::string usfm, std::string stylesheet, std::string & html);
void editone_logic_suffix_html (std::string editable_last_p_style, std::string usfm, std::string stylesheet, std::string & html);
std::string editone_logic_html_to_usfm (std::string stylesheet, std::string html);
void editone_logic_move_notes_v2 (std::string & prefix, std::string & suffix);
